<template>
  <div v-loading="wholeLoading" class="base-page-wrapper sale-detail">
    <el-bus-form
      ref="form"
      label-width="auto"
      :content="formContent"
      readonly
      class="readonly-form"
    >
      <template #id:baseInfo>
        <el-bus-title title="基本信息" size="small"></el-bus-title>
      </template>
      <template #id:refundInfo>
        <div class="base-page-wrapper__line"></div>
        <el-bus-title title="退款信息" size="small"></el-bus-title>
      </template>
      <template #id:goodsInfo>
        <div class="base-page-wrapper__line"></div>
        <el-bus-title title="商品信息" size="small"></el-bus-title>
      </template>
    </el-bus-form>
    <div class="text-center mt-20">
      <el-button class="min-w-100" @click="goBack">返回</el-button>
    </div>
  </div>
</template>

<script>
import VideoList from '@/components/order/video-list'
export default {
  data() {
    return {
      detail: {},
      wholeLoading: false,
      loading: false,
      formContent: [
        {
          type: 'row',
          id: 'baseInfo',
          items: [
            { label: '订单号：', id: 'orderNo', type: 'input' },
            { label: '下单时间：', id: 'orderTime', type: 'input' },
            { label: '申请时间：', id: 'createTime', type: 'input' },
            { label: '审核时间：', id: 'auditTime', type: 'input' },
            { label: '收货人：', id: 'customer', type: 'input' },
            { label: '收货人电话：', id: 'customerTel', type: 'input' },
            { label: '收货地址：', id: 'customerWholeAddress', type: 'input' },
          ],
        },
        {
          type: 'row',
          id: 'refundInfo',
          items: [
            { id: 'status', type: 'input', hidden: () => true },
            {
              label: '订单状态：',
              id: 'statusStr',
              component: 'simple-text',
              el: (row) => ({
                type: row.status === 'PENDING' ? 'primary' : '',
              }),
              forceDisabled: true,
            },
            { label: '售后单号：', id: 'salesNo', type: 'input' },
            { label: '退款金额(元)：', id: 'totalFee', type: 'input' },
            { label: '供应商扣款(元)：', id: 'feeSupplier', type: 'input' },
            { label: '平台扣款(元)：', id: 'feePlatform', type: 'input' },
            { label: '合伙人扣款(元)：', id: 'feePartner', type: 'input' },
            { label: '打包扣款(元)：', id: 'feePlatformPack', type: 'input' },
            { label: '质检扣款(元)：', id: 'feePlatformCheck', type: 'input' },
            {
              label: '物流扣款(元)：',
              id: 'feePlatformTransport',
              type: 'input',
            },
            { label: '实际总扣款(元)：', id: 'totalFee', type: 'input' },
            {
              label: '申请理由：',
              id: 'reason',
              type: 'input',
              el: { type: 'textarea' },
              span: 24,
            },
            {
              label: '平台回复：',
              id: 'remarks',
              type: 'input',
              el: { type: 'textarea' },
              span: 24,
            },
            {
              label: '退款图片：',
              id: 'pictureList',
              type: 'bus-upload',
              el: {
                listType: 'picture-card',
                size: 'small',
              },
              forceDisabled: true,
              span: 24,
              inputFormat: (row) => {
                if ('pictureList' in row) {
                  return row?.pictureList?.length
                    ? row.pictureList.map((i) => ({ url: i }))
                    : []
                }
              },
            },
            {
              label: '退款视频：',
              id: 'videoList',
              component: VideoList,
              forceDisabled: true,
              span: 24,
            },
          ],
        },
        {
          type: 'row',
          id: 'goodsInfo',
          items: [
            { label: '商品名称：', id: 'flowerName' },
            { label: '商品分类：', id: 'flowerCategory' },
            { label: '级别：', id: 'flowerLevelStr' },
            { label: '颜色：', id: 'flowerColor' },
            { label: '规格：', id: 'flowerUnit' },
            { label: '原价(元)：', id: 'price' },
            { label: '券后单价(元)：', id: 'realPrice' },
            { label: '券后总金额(元)：', id: 'realTotal' },
            { label: '供应商价格(元)：', id: 'supplierPrice' },
            { label: '合伙人加价(元)：', id: 'markupPartner' },
            { label: '申请数量：', id: 'num' },
            { label: '实际退款(元)：', id: 'totalFee' },
          ],
        },
      ],
    }
  },
  head() {
    return {
      title: '售后详情',
    }
  },
  computed: {
    editable() {
      return (
        this.$route.params.action === 'handle' &&
        this.detail?.status === 'PENDING'
      )
    },
  },
  mounted() {
    this.getDetail()
  },
  methods: {
    goBack() {
      this.$router.back()
    },
    async getDetail() {
      this.wholeLoading = true
      const { code, data } = await this.$elBusHttp.request(
        'flower/api/sales/list/view',
        { params: { id: this.$route.params.id } }
      )
      if (code === 0 && data) {
        data.customerWholeAddress = `${data.customerProvince || ''}${
          data.customerCity || ''
        }${data.customerRegion || ''}${data.customerAddress || ''}`
        this.detail = data || {}
        this.$refs.form.updateForm(data)
      }
      this.wholeLoading = false
    },
  },
}
</script>

<style lang="scss" scoped>
.sale-detail {
  border-radius: 0;
  .el-bus-title {
    margin-bottom: 10px;
  }
}
</style>
